@@ -5,15 +5,25 @@ from pathlib import Path
 from transparentpath import TransparentPath
 
 
+def process_token(token, token_file):
+    if token is not None:
+        if not token_file.is_file():
+            with open(str(token_file), "w") as ofile:
+                ofile.write(token)
+        if "2" in str(token_file):
+            os.environ["GOOGLE_APPLICATION_CREDENTIALS_2"] = str(token_file)
+        else:
+            os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = str(token_file)
+
+
 @pytest.fixture
 def clean(pytestconfig):
     token_file = Path("cred.json")
+    token_file2 = Path("cred2.json")
     token = pytestconfig.getoption("token")
-    if token is not None:
-        if not token_file.is_file():
-            with open("cred.json", "w") as ofile:
-                ofile.write(token)
-        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = str(token_file)
+    token2 = pytestconfig.getoption("token2")
+    process_token(token, token_file)
+    process_token(token2, token_file2)
 
     TransparentPath._do_update_cache = True
     TransparentPath._do_check = True
@@ -36,3 +46,4 @@ def clean(pytestconfig):
 
 def pytest_addoption(parser):
     parser.addoption("--token", action="store", default=None)
+    parser.addoption("--token2", action="store", default=None)
